[<prev] [next>] [day] [month] [year] [list]
Message-Id: <200811220020.53641.rusty@rustcorp.com.au>
Date: Sat, 22 Nov 2008 00:20:53 +1030
From: Rusty Russell <rusty@...tcorp.com.au>
To: Ralph Campbell <infinipath@...gic.com>
Cc: linux-kernel@...r.kernel.org
Subject: [PATCH 3/3] cpumask: use new cpumask API in drivers/infiniband/hw/ipath
Impact: cleanup
We're moving from handing around cpumask_t's to handing around struct
cpumask *'s. cpus_*, cpumask_t and cpu_*_map are deprecated: convert
to cpumask_*, cpu_*_mask.
Signed-off-by: Rusty Russell <rusty@...tcorp.com.au>
Cc: Ralph Campbell <infinipath@...gic.com>
---
drivers/infiniband/hw/ipath/ipath_file_ops.c | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
diff -r c68644561092 drivers/infiniband/hw/ipath/ipath_file_ops.c
--- a/drivers/infiniband/hw/ipath/ipath_file_ops.c Thu Nov 20 14:02:15 2008 +1030
+++ b/drivers/infiniband/hw/ipath/ipath_file_ops.c Thu Nov 20 14:04:38 2008 +1030
@@ -1674,7 +1674,7 @@
* InfiniPath chip to that processor (we assume reasonable connectivity,
* for now). This code assumes that if affinity has been set
* before this point, that at most one cpu is set; for now this
* is reasonable. I check for both cpus_empty() and cpus_full(),
* in case some kernel variant sets none of the bits when no
* affinity is set. 2.6.11 and 12 kernels have all present
* cpus set. Some day we'll have to fix it up further to handle
@@ -1683,11 +1683,11 @@
* information. There may be some issues with dual core numbering
* as well. This needs more work prior to release.
*/
- if (!cpus_empty(current->cpus_allowed) &&
- !cpus_full(current->cpus_allowed)) {
+ if (!cpumask_empty(¤t->cpus_allowed) &&
+ !cpumask_full(¤t->cpus_allowed)) {
int ncpus = num_online_cpus(), curcpu = -1, nset = 0;
for (i = 0; i < ncpus; i++)
- if (cpu_isset(i, current->cpus_allowed)) {
+ if (cpumask_test_cpu(i, ¤t->cpus_allowed)) {
ipath_cdbg(PROC, "%s[%u] affinity set for "
"cpu %d/%d\n", current->comm,
current->pid, i, ncpus);
@@ -1674,7 +1674,7 @@
* for now). This code assumes that if affinity has been set
* before this point, that at most one cpu is set; for now this
- * is reasonable. I check for both cpus_empty() and cpus_full(),
+ * is reasonable. I check for both cpumask_empty() and cpumask_full(),
* in case some kernel variant sets none of the bits when no
* affinity is set. 2.6.11 and 12 kernels have all present
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/
Powered by blists - more mailing lists